#ident "$Id: internals.h,v 1.3 2001/10/19 06:19:50 hpa Exp $"
/* ----------------------------------------------------------------------- *
 *   
 *   Copyright 2000-2001 H. Peter Anvin - All Rights Reserved
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU Lesser General Public License as
 *   published by the Free Software Foundation, Inc.,
 *   59 Temple Place Ste 330, Boston MA 02111-1307, USA, version 2.1,
 *   incorporated herein by reference.
 *
 * ----------------------------------------------------------------------- */

/*
 * internals.h
 *
 * Internals for object store
 */

#ifndef OBJSTORE_INTERNALS_H
#define OBJSTORE_INTERNALS_H

#include "lpsm.h"		/* Main include file */
#include "system.h"		/* System-specific constants */

struct ObjStore {
  int main_fd;			/* Primary file descriptor */
  int log_fd;			/* Log file descriptor */
  int pagesize;			/* Page size */
  int pageshift;		/* log2(pagesize) */
  void *arena;			/* Mapped memory zone */
  size_t arena_len;		/* Length of arena */
  char *pageinfo;		/* Page info pointer */
  size_t loaded_count;		/* Loaded pages count (accounting) */
  size_t dirty_count;		/* Dirty pages count (accounting) */
  struct sigaction oldact;	/* Previous signal action */
  size_t fork_seq;		/* Sequence number of forked processes */
};

enum ObjStore_RecordType {
  osrec_page,			/* Page data */
  osrec_commit,			/* Commit record */
};

#define LOGRECORD_MAGIC 0x9247746e

struct ObjStore_LogRecord {
  unsigned int  magic;		/* Magic number; for verification */
  unsigned int record_type;	/* Record */
  size_t size;			/* Data byte count (sequence # for commit) */
  off_t offset;			/* Offset of data */
};

extern struct ObjStore *lpsm_os_struct;

#endif
