#ident "$Id: lpsm.h,v 1.11 2001/10/19 06:19:50 hpa Exp $"
/* ----------------------------------------------------------------------- *
 *   
 *   Copyright 2000-2001 H. Peter Anvin - All Rights Reserved
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU Lesser General Public License as
 *   published by the Free Software Foundation, Inc.,
 *   59 Temple Place Ste 330, Boston MA 02111-1307, USA, version 2.1,
 *   incorporated herein by reference.
 *
 * ----------------------------------------------------------------------- */

/*
 * lpsm.h
 *
 * Public header file for the Linux Persistent Memory
 */

#ifndef LPSM_H
#define LPSM_H

#include <stdlib.h>
#include <signal.h>
#include <inttypes.h>
#include <sys/types.h>

/* Low-level core routines */

/* When checkpointing, specify the level of synchronicity required */
enum psmsync {
  PSMSYNC_NONE,			/* No synchronicity */
  PSMSYNC_SKIP,			/* Skip if previous writeback still running */
  PSMSYNC_WAIT,			/* Wait if previous writeback still running */
  PSMSYNC_SYNC			/* Wait until this writeback finishes */
};

void *lpsm_arena_init(const char *, const char *, size_t *);
pid_t lpsm_checkpoint(double, enum psmsync);
int lpsm_extend(size_t);
void lpsm_shutdown(void);

/* Arena management routines */

/* The allocator gives us this many "root pointers" for our own use.  They
   are initialized to NULL when a new arena is created, and are intended
   to be used to find all the data structures.  lpsm_arena_init()
   returns a pointer to this array (if successful). */
#define LPSM_ROOT_POINTERS	32

void **lpsm_init(const char *, const char *);
void *lpsm_malloc(size_t);
void lpsm_free(void *);
void *lpsm_realloc(void *, size_t);
struct lpsm_alloc_stats {
  size_t size;
  size_t free;
  size_t alloc;
};
struct lpsm_alloc_stats *lpsm_alloc_stats(void);

#endif /* LPSM_H */
